import { APIClient } from "./ApiClient";

export interface TokenRight {
  verb: "POST" | "GET" | "PUT" | "DELETE" | "PATCH";
  path: string;
}

export interface APIToken {
  id: string;
  name: string;
  description: string;
  created: number;
  updated: number;
  rights: TokenRight[];
  last_used: number;
  ip_restriction?: string;
  max_inactivity?: number;
}

export function APITokenURL(t: APIToken, edit: boolean = false): string {
  return `/tokens/${t.id}${edit ? "/edit" : ""}`;
}

export class TokensApi {
  /**
   * Get the full list of tokens
   */
  static async GetList(): Promise<APIToken[]> {
    return (
      await APIClient.exec({
        method: "GET",
        uri: "/tokens/list",
      })
    ).data;
  }
}
